Welcome to pyelectro’s documentation! — pyelectro 0.1.7 documentation

# Welcome to pyelectro’s documentation!

Tool for analysis of electrophysiology in Python.

This package was originally developed by Mike Vella. This has been updated by Padraig Gleeson and others (and moved to NeuralEnsemble) to continue development of pyelectro and Neurotune for use in OpenWorm, Open Source Brain and other projects

Contents:

# Source documentation

- pyelectro Package
  - `analysis` Module

# Indices and tables

- Index
- Module Index
- Search Page